A lightweight vector database for text retrieval in R with embedded machine learning models and no external API (Application Programming Interface) keys. Supports dense and hybrid search, optional HNSW (Hierarchical Navigable Small World) approximate nearest-neighbor indexing, faceted filters with ACL (Access Control List) metadata, command-line tools, and a local dashboard built with 'shiny'.
VectrixDB is a lightweight vector database with embedded machine learning models
that do not require external API (application programming interface) keys.
It supports dense, hybrid, and graph-based search modes and includes a built-in
dashboard.